@@ -10,6 +10,8 @@
 
 #include "Common.h"
 #include "Distribution.h"
+#include "FieldStatistics.h"
+#include "FieldConfig.h"
 #include "Field.h"
 #include "PathSegmentStorage.h"
 #include "Region.h"
